Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(480)

Unified Diff: components/mus/ws/event_dispatcher_delegate.h

Issue 2089023002: Promotes remaining global window manager state into WindowManagerState (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: override Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/ws/event_dispatcher.cc ('k') | components/mus/ws/event_dispatcher_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/event_dispatcher_delegate.h
diff --git a/components/mus/ws/event_dispatcher_delegate.h b/components/mus/ws/event_dispatcher_delegate.h
index be41e5c5585aead59d52950575323b76479010d3..1d31fb99d509602490e7d62411285e9edc738863 100644
--- a/components/mus/ws/event_dispatcher_delegate.h
+++ b/components/mus/ws/event_dispatcher_delegate.h
@@ -9,6 +9,10 @@
#include "components/mus/common/types.h"
+namespace gfx {
+class Point;
+}
+
namespace ui {
class Event;
}
@@ -27,14 +31,15 @@ class EventDispatcherDelegate {
virtual void SetFocusedWindowFromEventDispatcher(ServerWindow* window) = 0;
virtual ServerWindow* GetFocusedWindowForEventDispatcher() = 0;
- // Called when capture should be set on the native display.
- virtual void SetNativeCapture() = 0;
+ // Called when capture should be set on the native display. |window| is the
+ // window capture is being set on.
+ virtual void SetNativeCapture(ServerWindow* window) = 0;
// Called when the native display is having capture released. There is no
// longer a ServerWindow holding capture.
virtual void ReleaseNativeCapture() = 0;
// Called when |window| has lost capture. The native display may still be
// holding capture. The delegate should not change native display capture.
- // ReleaseNativeCapture is invoked if appropriate.
+ // ReleaseNativeCapture() is invoked if appropriate.
virtual void OnServerWindowCaptureLost(ServerWindow* window) = 0;
virtual void OnMouseCursorLocationChanged(const gfx::Point& point) = 0;
@@ -50,6 +55,10 @@ class EventDispatcherDelegate {
virtual ClientSpecificId GetEventTargetClientId(const ServerWindow* window,
bool in_nonclient_area) = 0;
+ // Returns the window to start searching from at the specified location, or
+ // null if there is a no window containing |location|.
+ virtual ServerWindow* GetRootWindowContaining(const gfx::Point& location) = 0;
+
// Called when event dispatch could not find a target. OnAccelerator may still
// be called.
virtual void OnEventTargetNotFound(const ui::Event& event) = 0;
« no previous file with comments | « components/mus/ws/event_dispatcher.cc ('k') | components/mus/ws/event_dispatcher_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698